@@ -1,6 +1,4 @@
 module.exports = {
 	description: 'correctly exports a default import, even in ES mode (#513)',
-	options: {
-		name: 'myBundle'
-	}
+	options: { output: { name: 'myBundle' } }
 };
