@@ -1,8 +1,10 @@
 module.exports = {
 	description: 'allows globals to be specified as a function',
 	options: {
-		globals: function ( id ) {
-			return id.replace( /-/g, '_' );
+		output: {
+			globals(id) {
+				return id.replace(/-/g, '_');
+			}
 		}
 	}
 };
