@@ -1,6 +1,4 @@
 module.exports = {
 	description: 'allow globals to be exported and imported',
-	options: {
-		name: 'doc'
-	}
+	options: { output: { name: 'doc' } }
 };
