@@ -1,7 +1,6 @@
 module.exports = {
 	description: 'getInterop with interop: false',
 	options: {
-		name: 'foo',
-		interop: false
+		output: { name: 'foo', interop: false },
 	}
 };
