@@ -1,6 +1,6 @@
 module.exports = {
 	description: 'external paths (#754)',
 	options: {
-		paths: id => `https://unpkg.com/${id}`
+		output: { paths: id => `https://unpkg.com/${id}` }
 	}
 };
