@@ -1,8 +1,6 @@
 module.exports = {
 	description: 'external paths (#754)',
 	options: {
-		paths: {
-			foo: 'https://unpkg.com/foo'
-		}
+		output: { paths: { foo: 'https://unpkg.com/foo' } }
 	}
 };
