@@ -2,6 +2,6 @@ module.exports = {
 	description: 'uses const instead of var if specified (#653)',
 	options: {
 		preferConst: true,
-		name: 'myBundle'
+		output: { name: 'myBundle' }
 	}
 };
