@@ -1,19 +1,17 @@
-var assert = require( 'assert' );
-
 module.exports = {
 	description: 'throws error only with first plugin transformBundle',
 	options: {
 		plugins: [
 			{
 				name: 'plugin1',
-				transformBundle: function () {
-					throw Error( 'Something happened 1' );
+				transformBundle() {
+					throw Error('Something happened 1');
 				}
 			},
 			{
 				name: 'plugin2',
-				transformBundle: function () {
-					throw Error( 'Something happened 2' );
+				transformBundle() {
+					throw Error('Something happened 2');
 				}
 			}
 		]
@@ -21,6 +19,7 @@ module.exports = {
 	generateError: {
 		code: 'BAD_BUNDLE_TRANSFORMER',
 		plugin: 'plugin1',
+		hook: 'transformBundle',
 		message: `Error transforming bundle with 'plugin1' plugin: Something happened 1`
 	}
 };
