@@ -1,5 +1,3 @@
-const assert = require( 'assert' );
-
 module.exports = {
 	description: 'warns on unused imports ([#595])',
 	warnings: [
@@ -8,17 +6,13 @@ module.exports = {
 			importer: 'main.js',
 			source: 'external',
 			message: `'external' is imported by main.js, but could not be resolved – treating it as an external dependency`,
-			url: `https://github.com/rollup/rollup/wiki/Troubleshooting#treating-module-as-external-dependency`
+			url: `https://rollupjs.org/guide/en#warning-treating-module-as-external-dependency`
 		},
 		{
 			code: 'UNUSED_EXTERNAL_IMPORT',
 			source: 'external',
-			names: ['unused', 'notused', 'neverused'],
-			message: `'unused', 'notused' and 'neverused' are imported from external module 'external' but never used`
-		},
-		{
-			code: 'EMPTY_BUNDLE',
-			message: `Generated an empty bundle`
+			names: ['notused', 'neverused'],
+			message: `'notused' and 'neverused' are imported from external module 'external' but never used`
 		}
 	]
 };
