@@ -143,14 +143,8 @@ describe('incremental', () => {
 					asts[module.id] = module.ast;
 				});
 
-				assert.deepEqual(
-					asts.entry,
-					acorn.parse(modules.entry, { sourceType: 'module' })
-				);
-				assert.deepEqual(
-					asts.foo,
-					acorn.parse(modules.foo, { sourceType: 'module' })
-				);
+				assert.deepEqual(asts.entry, acorn.parse(modules.entry, { sourceType: 'module' }));
+				assert.deepEqual(asts.foo, acorn.parse(modules.foo, { sourceType: 'module' }));
 			});
 	});
 
@@ -193,7 +187,7 @@ describe('incremental', () => {
 			});
 	});
 
-	it('separates resolvedIds from resolvedExternalIds', () => {
+	it('combines resolvedIds from resolvedExternalIds', () => {
 		modules = {
 			entry: `import foo from 'foo'; import external from 'external'; console.log(foo(external));`,
 			foo: `export default 42`
@@ -208,14 +202,11 @@ describe('incremental', () => {
 			.then(bundle => {
 				assert.deepEqual(bundle.imports, ['external']);
 
-				assert.equal(bundle.modules[0].id, 'foo');
-				assert.equal(bundle.modules[1].id, 'entry');
+				assert.equal(bundle.modules[1].id, 'foo');
+				assert.equal(bundle.modules[0].id, 'entry');
 
-				assert.deepEqual(bundle.modules[1].resolvedIds, {
-					foo: 'foo'
-				});
-
-				assert.deepEqual(bundle.modules[1].resolvedExternalIds, {
+				assert.deepEqual(bundle.modules[0].resolvedIds, {
+					foo: 'foo',
 					external: 'external'
 				});
 			});
